@@ -12,17 +12,20 @@
 )
 
 # Setup helpers
+julia_cli <- function(x) {
+  utils::tail(system2("julia", x, stdout = TRUE), 1L)
+}
 parse_julia_version <- function(version) {
-  gsub("^.*(\\d+\\.\\d+\\.\\d+).*$", "\\1", version)
+  gsub("^julia.version .*(\\d+\\.\\d+\\.\\d+).*$", "\\1", version)
 }
 julia_version <- function() {
-  parse_julia_version(system2("julia", "--version", stdout = TRUE))
+  parse_julia_version(julia_cli("--version"))
 }
 julia_version_compatible <- function() {
   as.package_version(julia_version()) >= "1.8"
 }
 julia_detect_cores <- function() {
-  as.integer(system2("julia", '-q -e "println(Sys.CPU_THREADS);"', stdout = TRUE))
+  as.integer(julia_cli('-q -e "println(Sys.CPU_THREADS);"'))
 }
 is_setup <- function() isTRUE(.jlmerclusterperm$is_setup)
 
